==> designer-asset-1.0.10-20251127.072942-12-sources.jar: com/digiwin/athena/dao/mongodao/assembly/impl/RDesignerMongoDaoImpl.java <==
package com.digiwin.athena.dao.mongodao.assembly.impl;

import cn.hutool.core.util.ObjectUtil;
import com.digiwin.athena.bo.assembly.Designer;
import com.digiwin.athena.constants.enums.assembly.OnlineState;
import com.digiwin.athena.convertor.assembly.DesignerConvertor;
import com.digiwin.athena.dao.mongodao.assembly.DDesignerMongoDao;
import com.digiwin.athena.dao.mongodao.assembly.RDesignerMongoDao;
import com.digiwin.athena.dto.PageReqCondition;
import com.digiwin.athena.dto.Pagination;
import com.digiwin.athena.dto.assembly.designer.DesignerListDTO;
import com.digiwin.athena.dto.assembly.designer.RDesignerPageQo;
import com.digiwin.athena.mongodb.domain.assembly.DesignerEntity;
import com.digiwin.athena.mongodb.repository.MongoRuntimeRepositoryDecorator;
import lombok.RequiredArgsConstructor;
import org.springframework.data.mongodb.core.query.Criteria;
import org.springframework.data.mongodb.core.query.Query;
import org.springframework.stereotype.Repository;

@RequiredArgsConstructor
@Repository
public class RDesignerMongoDaoImpl implements RDesignerMongoDao {
    private final MongoRuntimeRepositoryDecorator decorator;

    @Override
    public Designer selectById(String objectId) {
        return DesignerConvertor.INSTANCE.toBO(
                decorator.findById(objectId, DesignerEntity.class)
        );
    }

    @Override
    public Pagination<DesignerListDTO> selectOnlineDesignerPage(PageReqCondition<RDesignerPageQo> pageParam) {
        Query query = new Query();

        // 添加online状态条件
        query.addCriteria(Criteria.where(DesignerEntity.Fields.status).is(OnlineState.Online.getCode()));

        // 添加keyword查询条件
        RDesignerPageQo condition = ObjectUtil.defaultIfNull(pageParam.getCondition(), RDesignerPageQo::new);
        DDesignerMongoDao.addSearchNameOrType(query, condition.getSearchContent());

        return decorator
                .findWithPage(query, DesignerEntity.class, pageParam)
                .convert(DesignerConvertor.INSTANCE::toListDTO);
    }

    @Override
    public void save(Designer designer) {
        DesignerEntity entity = DesignerConvertor.INSTANCE.toPo(designer);
        entity.prepareSave();

        decorator.save(entity);

        designer.setId(entity.getId());
    }

    @Override
    public boolean deleteById(String objectId) {
        Query query = Query.query(Criteria.where(DesignerEntity.Fields.id).is(objectId));
        long count = decorator.remove(query, DesignerEntity.class);
        return count > 0;
    }
}

==> designer-asset-1.0.10-20251211.102111-50-sources.jar: com/digiwin/athena/dao/mongodao/assembly/impl/RDesignerMongoDaoImpl.java <==
package com.digiwin.athena.dao.mongodao.assembly.impl;

import cn.hutool.core.util.ObjectUtil;
import com.digiwin.athena.bo.assembly.Designer;
import com.digiwin.athena.constants.enums.assembly.OnlineState;
import com.digiwin.athena.convertor.assembly.DesignerConvertor;
import com.digiwin.athena.dao.mongodao.assembly.DDesignerMongoDao;
import com.digiwin.athena.dao.mongodao.assembly.RDesignerMongoDao;
import com.digiwin.athena.dto.PageReqCondition;
import com.digiwin.athena.dto.Pagination;
import com.digiwin.athena.dto.assembly.designer.DesignerDetailDTO;
import com.digiwin.athena.dto.assembly.designer.DesignerListDTO;
import com.digiwin.athena.dto.assembly.designer.RDesignerPageQo;
import com.digiwin.athena.mongodb.domain.assembly.DesignerEntity;
import com.digiwin.athena.mongodb.repository.MongoRuntimeRepositoryDecorator;
import lombok.RequiredArgsConstructor;
import org.springframework.data.mongodb.core.query.Criteria;
import org.springframework.data.mongodb.core.query.Query;
import org.springframework.stereotype.Repository;

import java.util.Collection;
import java.util.List;
import java.util.stream.Collectors;

@RequiredArgsConstructor
@Repository
public class RDesignerMongoDaoImpl implements RDesignerMongoDao {
    private final MongoRuntimeRepositoryDecorator decorator;

    @Override
    public Designer selectById(String objectId) {
        return DesignerConvertor.INSTANCE.toBO(
                decorator.findById(objectId, DesignerEntity.class)
        );
    }

    @Override
    public Pagination<DesignerListDTO> selectOnlineDesignerPage(PageReqCondition<RDesignerPageQo> pageParam) {
        Query query = new Query();

        // 添加online状态条件
        query.addCriteria(Criteria.where(DesignerEntity.Fields.status).is(OnlineState.Online.getCode()));

        // 添加keyword查询条件
        RDesignerPageQo condition = ObjectUtil.defaultIfNull(pageParam.getCondition(), RDesignerPageQo::new);
        DDesignerMongoDao.addSearchNameOrType(query, condition.getSearchContent());

        return decorator
                .findWithPage(query, DesignerEntity.class, pageParam)
                .convert(DesignerConvertor.INSTANCE::toListDTO);
    }

    @Override
    public void save(Designer designer) {
        DesignerEntity entity = DesignerConvertor.INSTANCE.toPo(designer);
        entity.prepareSave();

        decorator.save(entity);

        designer.setId(entity.getId());
    }

    @Override
    public boolean deleteById(String objectId) {
        Query query = Query.query(Criteria.where(DesignerEntity.Fields.id).is(objectId));
        long count = decorator.remove(query, DesignerEntity.class);
        return count > 0;
    }

    @Override
    public List<Designer> selectByIds(Collection<String> ids) {
        Query query = Query.query(Criteria.where(DesignerEntity.Fields.id).in(ids));
        return decorator.find(query,DesignerEntity.class).stream().map(DesignerConvertor.INSTANCE::toBO).collect(Collectors.toList());
    }
}
